<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Radio no válido</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Ninguna solución</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Seleccione la entidad o región</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Mover una entidad o un punto de referencia</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Segunda punto de esquina</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Especificar el punto de destino</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Especifique punto de destino</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Mover entidad</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Mover punto de referencia</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Desplazar selección</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Mover entidad</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Editar bloque &apos;%1&apos;&lt;br&gt;Elija &lt;i&gt;Bloque &gt; Volver al dibujo principal&lt;/i&gt; cuando se hace</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Atrás</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Herramienta activa:</translation>
    </message>
    <message>
        <source>Active Tool: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Herramienta activa: %1</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Opciones de bloque</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Herramientas principales</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>Herramientas CAD</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad está en una capa bloqueada.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Longitud:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad no es una referencia a bloque.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad no es una línea o un arco.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Entidad no es una línea, arco o polilínea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad no es una línea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad no es un arco o círculo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad no es una línea, arco o círculo.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad no es un arco, círculo o una elipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Entidad no es una línea, un arco, círculo o una elipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Entidad no es una línea, un arco, círculo, una elipse o polilínea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Entidad no es una línea, un arco, círculo, una elipse o una spline.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Entidad no es una línea, un arco, círculo, una elipse, una spline o polilínea.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad no es una polilínea.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Radio caído por debajo de 0,0 después %1 de círculos concéntricos.</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="vanished">Radio caído por debajo de 0,0 después %1 de arcos concéntricos.</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Por lo menos dos puntos son idénticos.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Ningún círculo es posible.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Ningún arco es posible.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>No válido número de segmentos:.%1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Inválida elipse mayor / menor: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Restaurar los valores predeterminados</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Insertar símbolo</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Diámetro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Grados</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Más / menos</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Casi igual</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asintóticamente igual</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Raíz cuadrada</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Alt phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Multiplicación</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Dividir</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Cuadrado</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Texto apilado</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Valor medido</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Alineado</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Ajuste</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Parte superior</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Base</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Parte inferior</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation>Sentido horario</translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation>Sentido antihorario</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation>Precedente</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation>Ninguno</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <source>Loading plugins...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cargar plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins...</source>
        <translation type="obsolete">Inicialización de plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Inicialización de plugins:</translation>
    </message>
    <message>
        <source>Post-initializing plugins...</source>
        <translation type="obsolete">Inicialización de plugins...</translation>
    </message>
    <message>
        <source>Post-Initialization...</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Después de la inicialización...</translation>
    </message>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Cargando complemento traducciones...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Cargar add-ons...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Inicialización de add-ons...</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Después de la inicialización...</translation>
    </message>
    <message>
        <source>Loading add-on translations ...</source>
        <translation type="obsolete">Cargando add-on traducciones ...</translation>
    </message>
    <message>
        <source>Loading add-ons ...</source>
        <translation type="obsolete">Cargar add-ons ...</translation>
    </message>
    <message>
        <source>Initializing add-ons ...</source>
        <translation type="obsolete">Inicialización de add-ons ...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Inicialización de add-ons:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons ...</source>
        <translation type="obsolete">Después de la inicialización ...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Objetos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Objeto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Objetos desconocido</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Objeto desconocida</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Bloques</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Bloque</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Capas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Capa</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Layouts</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Tipos de línea</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Tipo de línea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Vistas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Vista</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Entidad</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Entidades</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>3dFaces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>3dFace</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Referencias de bloque</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translatorcomment>--google--
Elija la referencia a bloque
Editar un bloque basado en una referencia a bloque elegido</translatorcomment>
        <translation>Referencia de bloque</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Referencias de bloque y atributos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Referencia de bloque y atributos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>Arcos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Arco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Atributos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Atributo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Definiciones de atributos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Definición de atributo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Círculos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Círculo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Dimensiones</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Dimensión</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimension</source>
        <translation>Cota alineada</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotas alineados</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimension</source>
        <translation>Cota angular</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimensions</source>
        <translation>Cotas angular</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation>Cotas angulares de 2 líneas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation>Cota angular de 2 líneas</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation>Cotas angulares de 3 puntos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation>Cota angular de 3 puntos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation>Dimensión del arco</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimension</source>
        <translation>Cota diametral</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotas diametral</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimension</source>
        <translation>Cota ordinal</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotas ordinal</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotas girado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cota girado</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimension</source>
        <translation>Cota radial</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimensions</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Cotas radiales</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Elipses</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Elipse</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatch</source>
        <translation>Rayado</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatches</source>
        <translatorcomment>--exact match--
--file: Explode_es.ts--
Dibujar sombreados y rellenos
Dibuja texturas y rellenos sólidos
Sombreado/Relleno</translatorcomment>
        <translation>Rayados</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Image</source>
        <translation>Imagen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Images</source>
        <translatorcomment>--exact match--
--file: grassmods_es.po--
La ruta base o url desde la que las imágenes y documentos pueden ser &quot;relativas&quot;
Imgenes</translatorcomment>
        <translation>Imgenes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leader</source>
        <translation>Directriz</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leaders</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Directrizes</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Líneas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Línea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Líneas infinitas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Línea infinita</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Rayos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Rayo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Puntos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Punto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Polilíneas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Polilínea</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solid</source>
        <translation>Sólido</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solids</source>
        <translatorcomment>--google--
en las líneas, los sólidos y los textos</translatorcomment>
        <translation>Sólidos</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Trazas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Trazo</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Caras</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Cara</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Basado en texto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Textos</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Ventanas</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Ventana</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidades desconocido</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Entidad desconocida</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Primera entidad no se pueden recortar.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Entidad no se pueden recortar.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Segunda entidad no se pueden recortar.</translation>
    </message>
</context>
</TS>
